#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""Collection of modules related to path, dir and files.
"""
import os
import shutil
from ..check import is_dir, is_exist, check_file_type

__all__ = ['del_dir_or_file', 'not_dir_mkdir']


def del_dir_or_file(dir_or_file: str) -> None:
    """
    """
    assert isinstance(dir_or_file, str)
    if is_dir(dir_or_file):
        shutil.rmtree(dir_or_file)
    if is_exist(dir_or_file):
        os.remove(dir_or_file)


def not_dir_mkdir(directory: str) -> None:
    """
    """
    assert isinstance(directory, str)
    if not is_dir(directory):
        os.mkdir(os.path.join(os.getcwd(), directory))


def not_type_append_type(directory: str, suffix: str) -> str:
    """
    """
    assert isinstance(directory, str)
    assert isinstance(suffix, str)
    if not check_file_type(directory, suffix):
        splited = directory.split('.')
        assert len(splited) == 1 or len(splited) == 2, 'Not work when directory contains `.` more than one.'
        prefix = splited[0]
        path = os.path.join(prefix, suffix)
    else:
        path = directory
    return path
    


    
    
 


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
"""
import os
import json
import logging
from .path import del_dir_or_file

__all__ = [
    'set_json_log', 
    'get_log_path',
    ]

DEF_LOG_PATH = os.path.join(os.path.dirname(__file__), 'logging.json')
DEF_INFO_PATH = 'info.log'
DEF_DEBUG_PATH = 'debug.log'


def get_log_path(env_vari: str='LOG_PATH') -> str:
    """
    """
    assert isinstance(env_vari, str)
    log_path = os.getenv(env_vari)
    if log_path is None:
        log_path = DEF_LOG_PATH
    return log_path


def set_json_log(
        json_path: str = DEF_LOG_PATH, 
        def_lvl: int = logging.INFO, 
        rm_old: bool = True) -> None:
    """Modified from: https://fangpenlin.com/posts/2012/08/26/good-logging-practice-in-python/
    Using json logging as the main logger.
    Should used in every files with: logger = logging.getLogger(__name__)
    """
    assert isinstance(rm_old, bool)
    assert isinstance(def_lvl, int)
    assert isinstance(json_path, str)
    if rm_old:
        del_dir_or_file(DEF_INFO_PATH)
        del_dir_or_file(DEF_DEBUG_PATH)
        
    if os.path.exists(json_path):
        with open(json_path, 'rt') as f:
            config = json.load(f)
        logging.config.dictConfig(config)
    else:
        raise FileNotFoundError(
                f'Cannot find json logging file from: {json_path}')

DEF_LOG_PATH = get_log_path()


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""A wrapper for zip the file.
TODO: testing Zipper.
"""
import os
import copy
import shutil
from zipfile import ZipFile
from path import not_type_append_type, not_dir_mkdir, del_dir_or_file
from check import is_exist, check_file_type

__all__ = ['Zipper']


class Zipper(object):
    def __init__(self, zip_name: str, file_loc: str = '.') -> None:
        assert isinstance(zip_name, str)
        self.file_loc = file_loc
        self.zip_name = not_type_append_type(zip_name)
        
    @classmethod
    def without_savedir(
            cls, zip_name: str, save_loc: str = '', file_loc: str = '.'):
        """Before construct, create a save_loc folder.
        """
        assert isinstance(save_loc, str)
        assert isinstance(file_loc, str)
        assert isinstance(zip_name, str)
        assert is_exist(file_loc)
        not_dir_mkdir(save_loc)
        path2zip = os.path.join(save_loc, zip_name)
        return cls(path2zip, file_loc)
    
    def zip_list(self, file_list: list) -> None:
        """Zip selected files in the file_list.
        """
        assert isinstance(file_list, list)
        with ZipFile(self.zip_name, 'w') as z:
            for file in file_list:
                path2file = os.path.join(self.file_loc, file)    
                z.write(path2file, file)

    def zip_all(self, save_py: bool = False, save_folder: bool = False) -> None:
        """Zip the all files into saveloc.
        """
        file_list = os.listdir(self.file_loc)
        file_list_tmp = copy.deepcopy(file_list)
        for i in file_list:
            if not save_py:
                if check_file_type(i, 'py'):
                    file_list_tmp.remove(i)
            if not save_folder: 
                if os.path.isdir(i):
                    file_list_tmp.remove(i)
        with ZipFile(self.zip_name, 'w') as z:
            for file in file_list_tmp:
                path2file = os.path.join(self.file_loc, file)    
                z.write(path2file, file)

    def unzip(self, dest_loc: str) -> None:
        """ Unzip the  to destloc.
        """
        assert isinstance(dest_loc, str)
        del_dir_or_file(dest_loc)
        with ZipFile(self.zip_name, 'r') as z:
            for file in z.namelist():
                z.extract(file, dest_loc)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
from .ninstd import *
from .namer import *
from .log import *
from . import check
from . import type
from . import path
from . import utils
from . import recorder
from . import error


__all__ = []
__all__ = ninstd.__all__
__all__ = namer.__all__
__all__ = log.__all__
__all__ += check.__all__
__all__ += type.__all__
__all__ += path.__all__
__all__ += utils.__all__
__all__ += recorder.__all__
__all__ += error.__all__


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""Collections of functions for asserting or checking.
Note that if the module is related to check, the priority is to put at here.
"""
import os
import sys
import shutil

__all__ = [
    'is_imported', 
    'is_dir', 
    'is_exist', 
    'check_file_type',
    ]


def is_imported(module: str) -> bool:
    """Check the module is load or not.
    From: https://stackoverflow.com/questions/30483246/how-to-check-if-a-python-module-has-been-imported
    """
    if module in sys.modules:
        return True
    else:
        return False

def is_dir(directory: str) -> bool:
    """Return True if that directory is dir. 
    """
    return os.path.isdir(os.path.join(os.getcwd(), directory))


def is_exist(directory: str) -> bool:
    """Return True if that directory is dir. 
    """
    return os.path.exists(os.path.join(os.getcwd(), directory))


def check_type_args(*args: str, type: str) -> bool:
    """Assert that all args has same type as type.
    """
    for arg in args:
        assert isinstance(arg, type)
    

def check_file_type(directory: str, suffix: str) -> None:
    """Split a file type from directory and check that is same as file_type or not.
    """
    assert isinstance(directory, str)
    return suffix == directory.split('.')[-1]




#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import setuptools

def get_version():
    return

with open('README.md', 'r') as fh:
    long_description = fh.read()


setuptools.setup(
    name='ninstd',
    version='0.4',
    author='Ninnart Fuengfusin',
    author_email='ninnart.fuengfusin@yahoo.com',
    description='A wrapper of Python using only standard libraries.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/ninfueng/ninstd',
    packages=setuptools.find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'License :: OSI Approved :: MIT License',
    ],
    python_requires='>=3.7',
)




#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import os
from datetime import datetime
try:
    from __main__ import __file__
except ImportError:
    pass

__all__ = ['Namer']


class Namer(object):
    """For create a name for hyper-parameter searching.
    namer = Namer(**{'test': 1, 'test2': 2})
    print(namer.gen_name())
    """
    def __init__(self, *args: str, **kwargs: dict) -> None:
        self.args = args
        self.kwargs = kwargs
    
    @staticmethod
    def get_foldername() -> str:
        """Return a string of folder name.
        """
        full_path = os.path.realpath(__file__)
        path, _ = os.path.split(full_path)
        _, folder_name = os.path.split(path)
        return folder_name
    
    @staticmethod
    def get_date() -> str:
        """Return a string of datetime.
        """
        return str(datetime.now().strftime('%y-%m-%d_%H-%M-%S'))

    @staticmethod
    def dot_to_dash(string) -> str:
        """From the input string, find . change into _.
        """
        assert isinstance(string, str)
        return string.replace('.', '-')

    @staticmethod
    def get_filename() -> str:
        """Return a string name of python scirpt.
        """
        return os.path.basename(__file__).replace('.py', '')
    
    def gen_name(self) -> str:
        """Generate the name.
        """
        folder = self.get_foldername()
        file = self.get_filename()
        date = self.get_date()
        name = f'{folder}_{file}_{date}'
        for kw in self.kwargs.keys():
            kw = self.dot_to_dash(kw)
            name += '_' + kw + str(self.kwargs[kw])
        for arg in self.args:
            arg = self.dot_to_dash(arg)
            name += '_' + str(arg)
        return name

    @classmethod
    def from_args(cls, args):
        """Using with parser.parse_args().
        """
        return cls(**vars(args))